@@ -24,7 +24,7 @@
 
 #include <assert.h>
 #include <QDebug>
-#include <QtCore/QHash>
+#include <QHash>
 #include <qstandardpaths.h>
 
 KBuildMimeTypeFactory::KBuildMimeTypeFactory(KSycoca *db)
@@ -51,18 +51,18 @@ KSycocaEntry *KBuildMimeTypeFactory::createEntry(const QString &file) const
     // file=text/plain.xml  ->  name=plain.xml dirName=text
     Q_ASSERT(!file.startsWith(QLatin1String("mime/")));
 
-    const int pos = file.lastIndexOf('/');
+    const int pos = file.lastIndexOf(QLatin1Char('/'));
     if (pos == -1) { // huh?
-        return 0;
+        return nullptr;
     }
     const QStringRef dirName = file.leftRef(pos);
     if (dirName == QLatin1String("packages")) { // special subdir
-        return 0;
+        return nullptr;
     }
 
-    const int dot = file.lastIndexOf('.');
+    const int dot = file.lastIndexOf(QLatin1Char('.'));
     if (dot == -1) { // huh?
-        return 0;
+        return nullptr;
     }
     const QString name = file.left(dot);
 
@@ -83,7 +83,7 @@ void KBuildMimeTypeFactory::save(QDataStream &str)
 
     str << qint32(0);
 
-    const int endOfFactoryData = str.device()->pos();
+    const qint64 endOfFactoryData = str.device()->pos();
 
     // Update header (pass #3)
     saveHeader(str);
